MethodChannelDeviceContextPlus class

Default implementation using MethodChannel

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAll() Future<Map<String, dynamic>>
Returns full device context (app + device)
override
getApp() Future<Map<String, dynamic>>
Returns application info
override
getDevice() Future<Map<String, dynamic>>
Returns device info
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited