DeviceContextPlusPlatform class abstract
Platform interface for DeviceContextPlus
Defines the contract that platform-specific implementations must follow.
- Inheritance
-
- Object
- PlatformInterface
- DeviceContextPlusPlatform
- Implementers
Constructors
- DeviceContextPlusPlatform()
- Constructs a DeviceContextPlusPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAll(
) → Future< Map< String, dynamic> > - Returns full device context (app + device)
-
getApp(
) → Future< Map< String, dynamic> > - Returns application info
-
getDevice(
) → Future< Map< String, dynamic> > - Returns device info
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ DeviceContextPlusPlatform
-
The default instance of DeviceContextPlusPlatform
getter/setter pair