InfoAll class
Aggregated device context information.
Combines:
- InfoApp (application data)
- InfoDevice (device data)
Constructors
- InfoAll({required InfoApp app, required InfoDevice device})
- Constructs an InfoAll instance.
-
InfoAll.fromMap(Map<
String, dynamic> map) -
Creates an instance from a Map returned by the native layer.
factory
Properties
- app → InfoApp
-
Application-related information.
final
- device → InfoDevice
-
Device-related information.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited