InfoApp class
Represents application-level information.
Contains platform-specific fields for both Android and iOS.
Constructors
- InfoApp({String? bundleId, String? version, String? build, String? packageName, int? versionCode, int? firstInstallTime, int? lastUpdateTime, String? installerStore, String? teamId})
- Creates a new InfoApp instance.
-
InfoApp.fromMap(Map<
String, dynamic> map) -
Creates an instance from native map data.
factory
Properties
- build → String?
-
iOS build number.
final
- bundleId → String?
-
iOS bundle identifier.
final
- firstInstallTime → int?
-
First installation timestamp (Android).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installerStore → String?
-
Installer source (Play Store, APK, etc.).
final
- lastUpdateTime → int?
-
Last update timestamp (Android).
final
- packageName → String?
-
Android package name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- teamId → String?
-
Apple Developer Team ID (iOS).
final
- version → String?
-
App version (iOS: version | Android: versionName).
final
- versionCode → int?
-
Android version code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited