InfoDevice class

Represents device and system information.

Includes hardware, OS, and locale details.

Constructors

InfoDevice({String? platform, String? model, String? name, String? manufacturer, String? brand, String? device, String? hardware, String? systemName, String? systemVersion, String? osVersion, int? sdkInt, String? locale, String? timezone, bool isEmulator = false})
Creates a new InfoDevice instance.
InfoDevice.fromMap(Map<String, dynamic> map)
Creates an instance from native map data.
factory

Properties

brand String?
Brand (Android).
final
device String?
Device identifier (Android)
final
hardware String?
Hardware identifier (Android).
final
hashCode int
The hash code for this object.
no setterinherited
isEmulator bool
Indicates if the app is running in an emulator/simulator (android or ios).
final
locale String?
Device locale.
final
manufacturer String?
Manufacturer (Android).
final
model String?
Device model.
final
name String?
Device name (iOS).
final
osVersion String?
OS version (Android).
final
platform String?
Platform name (android or ios).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkInt int?
Android SDK version.
final
systemName String?
System name (iOS).
final
systemVersion String?
System version (iOS).
final
timezone String?
Device timezone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited